@@ -1,3 +1,4 @@
+from classytags.compat import compat_basestring
 from classytags.exceptions import TemplateSyntaxWarning
 from django import template
 from django.conf import settings
@@ -43,8 +44,8 @@ class StrictStringValue(StringValue):
     value_on_error = ""
 
     def clean(self, value):
-        if not isinstance(value, basestring):
-            return self.error(value, 'type')
+        if not isinstance(value, compat_basestring):
+            return self.error(value, "clean")
         return value
 
 
